@@ -1,15 +1,15 @@
 from dataclasses import dataclass
 import logging
 import matplotlib.pyplot as plt
-from pathlib import Path
+from pathlib import Path, PurePosixPath
 
 import numpy as np
 import nrrd
 
-from brainbox.numerical import ismember
-from ibllib.atlas.regions import BrainRegions, regions_from_allen_csv  # noqa
-from ibllib.io import params
-from oneibl.webclient import http_download_file
+from iblutil.numerical import ismember
+from ibllib.atlas.regions import BrainRegions
+from one.webclient import http_download_file
+import one.params
 
 _logger = logging.getLogger('ibllib')
 ALLEN_CCF_LANDMARKS_MLAPDV_UM = {'bregma': np.array([5739, 5400, 332])}
@@ -716,18 +716,16 @@ class AllenAtlas(BrainAtlas):
     using the IBL Bregma and coordinate system
     """
 
-    def __init__(self, res_um=25, brainmap='Allen', scaling=np.array([1, 1, 1]),
-                 mock=False, hist_path=None):
+    def __init__(self, res_um=25, scaling=np.array([1, 1, 1]), mock=False, hist_path=None):
         """
         :param res_um: 10, 25 or 50 um
-        :param brainmap: defaults to 'Allen', see ibllib.atlas.BrainRegion for re-mappings
         :param scaling: scale factor along ml, ap, dv for squeeze and stretch ([1, 1, 1])
         :param mock: for testing purpose
         :param hist_path
         :return: atlas.BrainAtlas
         """
-        par = params.read('one_params')
-        FLAT_IRON_ATLAS_REL_PATH = Path('histology', 'ATLAS', 'Needles', 'Allen')
+        par = one.params.get(silent=True)
+        FLAT_IRON_ATLAS_REL_PATH = PurePosixPath('histology', 'ATLAS', 'Needles', 'Allen')
         LUT_VERSION = "v01"  # version 01 is the lateralized version
         regions = BrainRegions()
         xyz2dims = np.array([1, 0, 2])  # this is the c-contiguous ordering
@@ -744,11 +742,11 @@ class AllenAtlas(BrainAtlas):
             file_image = hist_path or path_atlas.joinpath(f'average_template_{res_um}.nrrd')
             # get the image volume
             if not file_image.exists():
-                _download_atlas_flatiron(file_image, FLAT_IRON_ATLAS_REL_PATH, par)
+                _download_atlas_allen(file_image, FLAT_IRON_ATLAS_REL_PATH, par)
             # get the remapped label volume
             file_label = path_atlas.joinpath(f'annotation_{res_um}.nrrd')
             if not file_label.exists():
-                _download_atlas_flatiron(file_label, FLAT_IRON_ATLAS_REL_PATH, par)
+                _download_atlas_allen(file_label, FLAT_IRON_ATLAS_REL_PATH, par)
             file_label_remap = path_atlas.joinpath(f'annotation_{res_um}_lut_{LUT_VERSION}.npz')
             if not file_label_remap.exists():
                 label = self._read_volume(file_label)
@@ -841,10 +839,30 @@ def NeedlesAtlas(*args, **kwargs):
     return AllenAtlas(*args, **kwargs)
 
 
-def _download_atlas_flatiron(file_image, FLAT_IRON_ATLAS_REL_PATH, par):
+def _download_atlas_allen(file_image, FLAT_IRON_ATLAS_REL_PATH, par):
+    """
+    © 2015 Allen Institute for Brain Science. Allen Mouse Brain Atlas (2015)
+    with region annotations (2017).
+    Available from: http://download.alleninstitute.org/informatics-archive/current-release/
+    mouse_ccf/annotation/
+    See Allen Mouse Common Coordinate Framework Technical White Paper for details
+    http://help.brain-map.org/download/attachments/8323525/
+    Mouse_Common_Coordinate_Framework.pdf?version=3&modificationDate=1508178848279&api=v2
+    """
+
     file_image.parent.mkdir(exist_ok=True, parents=True)
-    url = (par.HTTP_DATA_SERVER + '/' +
-           '/'.join(FLAT_IRON_ATLAS_REL_PATH.parts) + '/' + file_image.name)
-    http_download_file(url, cache_dir=Path(par.CACHE_DIR).joinpath(FLAT_IRON_ATLAS_REL_PATH),
-                       username=par.HTTP_DATA_SERVER_LOGIN,
-                       password=par.HTTP_DATA_SERVER_PWD)
+
+    template_url = ('http://download.alleninstitute.org/informatics-archive/'
+                    'current-release/mouse_ccf/average_template')
+    annotation_url = ('http://download.alleninstitute.org/informatics-archive/'
+                      'current-release/mouse_ccf/annotation/ccf_2017')
+
+    if file_image.name.split('_')[0] == 'average':
+        url = template_url + '/' + file_image.name
+    elif file_image.name.split('_')[0] == 'annotation':
+        url = annotation_url + '/' + file_image.name
+    else:
+        raise ValueError('Unrecognized file image')
+
+    cache_dir = Path(par.CACHE_DIR).joinpath(FLAT_IRON_ATLAS_REL_PATH)
+    return http_download_file(url, cache_dir=cache_dir)
