@@ -8,12 +8,12 @@ import shutil
 import numpy as np
 import pandas as pd
 from scipy import signal
+import one.alf.io as alfio
+from iblutil.util import Bunch
 
-import alf.io
-from brainbox.core import Bunch
 from brainbox.metrics.single_units import spike_sorting_metrics
 from ibllib.ephys import sync_probes
-from ibllib.io import spikeglx, raw_data_loaders
+from ibllib.io import spikeglx
 import ibllib.dsp as dsp
 from ibllib.io.extractors import ephys_fpga, training_wheel
 from ibllib.misc import print_progress
@@ -36,8 +36,7 @@ def rmsmap(fbin):
     :return: a dictionary with amplitudes in channeltime space, channelfrequency space, time
      and frequency scales
     """
-    if not isinstance(fbin, spikeglx.Reader):
-        sglx = spikeglx.Reader(fbin)
+    sglx = spikeglx.Reader(fbin, open=True)
     rms_win_length_samples = 2 ** np.ceil(np.log2(sglx.fs * RMS_WIN_LENGTH_SECS))
     # the window generator will generates window indices
     wingen = dsp.WindowGenerator(ns=sglx.ns, nswin=rms_win_length_samples, overlap=0)
@@ -65,6 +64,7 @@ def rmsmap(fbin):
         # print at least every 20 windows
         if (iw % min(20, max(int(np.floor(wingen.nwin / 75)), 1))) == 0:
             print_progress(iw, wingen.nwin)
+    sglx.close()
     return win
 
 
@@ -101,9 +101,9 @@ def extract_rmsmap(fbin, out_folder=None, overwrite=False):
     tdict = {'rms': rms['TRMS'].astype(np.single), 'timestamps': rms['tscale'].astype(np.single)}
     fdict = {'power': rms['spectral_density'].astype(np.single),
              'freqs': rms['fscale'].astype(np.single)}
-    out_time = alf.io.save_object_npy(
+    out_time = alfio.save_object_npy(
         out_folder, object=alf_object_time, dico=tdict, namespace='iblqc')
-    out_freq = alf.io.save_object_npy(
+    out_freq = alfio.save_object_npy(
         out_folder, object=alf_object_freq, dico=fdict, namespace='iblqc')
     return out_time + out_freq
 
@@ -283,7 +283,7 @@ def qc_fpga_task(fpga_trials, alf_trials):
     :fpga_task is the dictionary output of
     ibllib.io.extractors.ephys_fpga.extract_behaviour_sync
     : bpod_trials is the dictionary output of ibllib.io.extractors.ephys_trials.extract_all
-    : alf_trials is the ALF _ibl_trials object after extraction (alf.io.load_object)
+    : alf_trials is the ALF _ibl_trials object after extraction (alfio.load_object)
     :return: qc_session, qc_trials, True means QC passes while False indicates a failure
     """
 
@@ -393,17 +393,13 @@ def _qc_from_path(sess_path, display=True):
     temp_alf_folder = sess_path.joinpath('fpga_test', 'alf')
     temp_alf_folder.mkdir(parents=True, exist_ok=True)
 
-    raw_trials = raw_data_loaders.load_data(sess_path)
-    tmax = raw_trials[-1]['behavior_data']['States timestamps']['exit_state'][0][-1] + 60
-
     sync, chmap = ephys_fpga.get_main_probe_sync(sess_path, bin_exists=False)
     _ = ephys_fpga.extract_all(sess_path, output_path=temp_alf_folder, save=True)
     # check that the output is complete
-    fpga_trials = ephys_fpga.extract_behaviour_sync(sync, output_path=temp_alf_folder, tmax=tmax,
-                                                    chmap=chmap, save=True, display=display)
+    fpga_trials = ephys_fpga.extract_behaviour_sync(sync, chmap=chmap, display=display)
     # align with the bpod
     bpod2fpga = ephys_fpga.align_with_bpod(temp_alf_folder.parent)
-    alf_trials = alf.io.load_object(temp_alf_folder, 'trials')
+    alf_trials = alfio.load_object(temp_alf_folder, 'trials')
     shutil.rmtree(temp_alf_folder)
     # do the QC
     qcs, qct = qc_fpga_task(fpga_trials, alf_trials)
@@ -427,4 +423,4 @@ def _qc_from_path(sess_path, display=True):
             axes[1].plot(bpod2fpga(bpod_wheel['re_ts']), bpod_wheel['re_pos'] + dy)
             axes[1].title.set_text('Bpod')
 
-    return alf.io.dataframe({**fpga_trials, **alf_trials, **qct})
+    return alfio.dataframe({**fpga_trials, **alf_trials, **qct})
