@@ -5,8 +5,8 @@ import shutil
 import tarfile
 
 import numpy as np
+from one.alf.files import get_session_path
 
-import alf.io
 import phylib.io.alf
 from ibllib.ephys.sync_probes import apply_sync
 import ibllib.ephys.ephysqc as ephysqc
@@ -27,7 +27,7 @@ def probes_description(ses_path, one=None, bin_exists=True):
         alf/probes.trajectory.npy
     """
 
-    eid = one.eid_from_path(ses_path)
+    eid = one.path2eid(ses_path, query_type='remote')
     ses_path = Path(ses_path)
     ephys_files = spikeglx.glob_ephys_files(ses_path, ext='meta')
     subdirs, labels, efiles_sorted = zip(
@@ -65,7 +65,7 @@ def probes_description(ses_path, one=None, bin_exists=True):
     bpod_meta = raw_data_loaders.load_settings(ses_path)
     if not bpod_meta.get('PROBE_DATA'):
         _logger.error('No probe information in settings JSON. Skipping probes.trajectory')
-        return
+        return []
 
     def prb2alf(prb, label):
         return {'label': label, 'x': prb['X'], 'y': prb['Y'], 'z': prb['Z'], 'phi': prb['A'],
@@ -121,7 +121,7 @@ def sync_spike_sorting(ap_file, out_path):
         ap_file.name.replace('.ap.', '.sync.')).with_suffix('.npy')
     # try to get probe sync if it doesn't exist
     if not sync_file.exists():
-        _, sync_files = sync_probes.sync(alf.io.get_session_path(ap_file))
+        _, sync_files = sync_probes.sync(get_session_path(ap_file))
         out_files.extend(sync_files)
     # if it still not there, full blown error
     if not sync_file.exists():
