@@ -5,7 +5,7 @@ import numpy as np
 from scipy import interpolate
 
 from ibllib.io.extractors import training_trials
-from ibllib.io.extractors.base import BaseBpodTrialsExtractor
+from ibllib.io.extractors.base import BaseBpodTrialsExtractor, run_extractor_classes
 import ibllib.io.raw_data_loaders as raw
 from ibllib.misc import structarr
 import ibllib.exceptions as err
@@ -88,8 +88,8 @@ def sync_rotary_encoder(session_path, bpod_data=None, re_events=None):
 
 def get_wheel_position(session_path, bp_data=None, display=False):
     """
-    Gets wheel timestamps and position. Position is in radian (constant above for radius is 1)
-    mathematical convention.
+    Gets wheel timestamps and position from Bpod data. Position is in radian (constant above for
+    radius is 1) mathematical convention.
     :param session_path:
     :param bp_data (optional): bpod trials read from jsonable file
     :param display (optional): (bool)
@@ -104,7 +104,7 @@ def get_wheel_position(session_path, bp_data=None, display=False):
         _logger.error('No wheel data for ' + str(session_path))
         return None, None
     data = structarr(['re_ts', 're_pos', 'bns_ts'],
-                     shape=(df.shape[0],), formats=['f8', 'f8', np.object])
+                     shape=(df.shape[0],), formats=['f8', 'f8', object])
     data['re_ts'] = df.re_ts.values
     data['re_pos'] = df.re_pos.values * -1  # anti-clockwise is positive in our output
     data['re_pos'] = data['re_pos'] / 1024 * 2 * np.pi  # convert positions to radians
@@ -232,6 +232,41 @@ def get_wheel_position(session_path, bp_data=None, display=False):
     return data['re_ts'], data['re_pos']
 
 
+def infer_wheel_units(pos):
+    """
+    Given an array of wheel positions, infer the rotary encoder resolution, encoding type and units
+
+    The encoding type varies across hardware (Bpod uses X1 while FPGA usually extracted as X4), and
+    older data were extracted in linear cm rather than radians.
+
+    :param pos: a 1D array of extracted wheel positions
+    :return units: the position units, assumed to be either 'rad' or 'cm'
+    :return resolution: the number of decoded fronts per 360 degree rotation
+    :return encoding: one of {'X1', 'X2', 'X4'}
+    """
+    if len(pos.shape) > 1:  # Ensure 1D array of positions
+        pos = pos.flatten()
+
+    # Check the values and units of wheel position
+    res = np.array([wh.ENC_RES, wh.ENC_RES / 2, wh.ENC_RES / 4])
+    # min change in rad and cm for each decoding type
+    # [rad_X4, rad_X2, rad_X1, cm_X4, cm_X2, cm_X1]
+    min_change = np.concatenate([2 * np.pi / res, wh.WHEEL_DIAMETER * np.pi / res])
+    pos_diff = np.median(np.abs(np.ediff1d(pos)))
+
+    # find min change closest to min pos_diff
+    idx = np.argmin(np.abs(min_change - pos_diff))
+    if idx < len(res):
+        # Assume values are in radians
+        units = 'rad'
+        encoding = idx
+    else:
+        units = 'cm'
+        encoding = idx - len(res)
+    enc_names = {0: 'X4', 1: 'X2', 2: 'X1'}
+    return units, int(res[encoding]), enc_names[int(encoding)]
+
+
 def extract_wheel_moves(re_ts, re_pos, display=False):
     """
     Extract wheel positions and times from sync fronts dictionary
@@ -251,30 +286,14 @@ def extract_wheel_moves(re_ts, re_pos, display=False):
         x = np.arange(re_pos.size)
         re_ts = np.interp(x, re_ts[:, 0], re_ts[:, 1])
 
-    # Check the values and units of wheel position
-    res = np.array([wh.ENC_RES, wh.ENC_RES / 2, wh.ENC_RES / 4])
-    # min change in rad and cm for each decoding type
-    # [rad_X4, rad_X2, rad_X1, cm_X4, cm_X2, cm_X1]
-    min_change = np.concatenate([2 * np.pi / res, wh.WHEEL_DIAMETER * np.pi / res])
-    pos_diff = np.median(np.abs(np.ediff1d(re_pos)))
-
-    # find min change closest to min pos_diff
-    idx = np.argmin(np.abs(min_change - pos_diff))
-    if idx < len(res):
-        # Assume values are in radians
-        units = 'rad'
-        encoding = idx
-    else:
-        units = 'cm'
-        encoding = idx - len(res)
-    enc_names = {0: 'X4', 1: 'X2', 2: 'X1'}
-    _logger.info('Wheel in %s units using %s encoding', units, enc_names[int(encoding)])
+    units, res, enc = infer_wheel_units(re_pos)
+    _logger.info('Wheel in %s units using %s encoding', units, enc)
 
     # The below assertion is violated by Bpod wheel data
     #  assert np.allclose(pos_diff, min_change, rtol=1e-05), 'wheel position skips'
 
     # Convert the pos threshold defaults from samples to correct unit
-    thresholds = wh.samples_to_cm(np.array([8, 1.5]), resolution=res[encoding])
+    thresholds = wh.samples_to_cm(np.array([8, 1.5]), resolution=res)
     if units == 'rad':
         thresholds = wh.cm_to_rad(thresholds)
     kwargs = {'pos_thresh': thresholds[0],
@@ -359,10 +378,11 @@ class Wheel(BaseBpodTrialsExtractor):
     Radians mathematical convention
     """
     save_names = ('_ibl_wheel.timestamps.npy', '_ibl_wheel.position.npy',
-                  '_ibl_wheelMoves.intervals.npy', '_ibl_wheelMoves.peakAmplitude.npy',
-                  '_ibl_trials.firstMovement_times.npy')
+                  '_ibl_wheelMoves.intervals.npy', '_ibl_wheelMoves.peakAmplitude.npy', None,
+                  '_ibl_trials.firstMovement_times.npy', None)
     var_names = ('wheel_timestamps', 'wheel_position', 'wheel_moves_intervals',
-                 'wheel_moves_peak_amplitude', 'firstMovement_times')
+                 'wheel_moves_peak_amplitude', 'peakVelocity_times', 'firstMovement_times',
+                 'is_final_movement')
 
     def _extract(self):
         ts, pos = get_wheel_position(self.session_path, self.bpod_trials)
@@ -376,11 +396,12 @@ class Wheel(BaseBpodTrialsExtractor):
         trials = {'goCue_times': goCue_times, 'feedback_times': feedback_times}
         min_qt = self.settings.get('QUIESCENT_PERIOD', None)
 
-        first_moves, *_ = extract_first_movement_times(moves, trials, min_qt=min_qt)
-
-        return ts, pos, moves['intervals'], moves['peakAmplitude'], first_moves
+        first_moves, is_final, _ = extract_first_movement_times(moves, trials, min_qt=min_qt)
+        output = (ts, pos, moves['intervals'], moves['peakAmplitude'],
+                  moves['peakVelocity_times'], first_moves, is_final)
+        return output
 
 
 def extract_all(session_path, bpod_trials=None, settings=None, save=False):
-    return Wheel(session_path=session_path).extract(
-        save=save, bpod_trials=bpod_trials, settings=settings)
+    return run_extractor_classes(Wheel, save=save, session_path=session_path,
+                                 bpod_trials=bpod_trials, settings=settings)
