@@ -10,6 +10,7 @@ import numpy as np
 import pandas as pd
 import one.alf.io as alfio
 
+from ibllib.misc import check_nvidia_driver
 from ibllib.ephys import ephysqc, spikes, sync_probes
 from ibllib.io import ffmpeg, spikeglx
 from ibllib.io.video import label_from_path
@@ -92,7 +93,7 @@ class SpikeSorting(tasks.Task):
         "Documents/PYTHON/iblscripts/deploy/serverpc/kilosort2/run_pykilosort.sh"
     )
     SPIKE_SORTER_NAME = 'pykilosort'
-    PYKILOSORT_REPO = '~/Documents/PYTHON/SPIKE_SORTING/pykilosort'
+    PYKILOSORT_REPO = Path.home().joinpath('Documents/PYTHON/SPIKE_SORTING/pykilosort')
 
     @staticmethod
     def _sample2v(ap_file):
@@ -100,6 +101,20 @@ class SpikeSorting(tasks.Task):
         s2v = spikeglx._conversion_sample2v_from_meta(md)
         return s2v["ap"][0]
 
+    @staticmethod
+    def _fetch_pykilosort_version(repo_path):
+        init_file = Path(repo_path).joinpath('pykilosort', '__init__.py')
+        version = SpikeSorting._fetch_ks2_commit_hash(repo_path)  # default
+        try:
+            with open(init_file) as fid:
+                lines = fid.readlines()
+                for line in lines:
+                    if line.startswith("__version__ = "):
+                        version = line.split('=')[-1].strip().replace('"', '').replace("'", '')
+        except Exception:
+            pass
+        return f"pykilosort_{version}"
+
     @staticmethod
     def _fetch_ks2_commit_hash(repo_path):
         command2run = f"git --git-dir {repo_path}/.git rev-parse --verify HEAD"
@@ -115,16 +130,6 @@ class SpikeSorting(tasks.Task):
             return ""
         return info.decode("utf-8").strip()
 
-    @staticmethod
-    def _check_nvidia():
-        # check the nvidia status before doing anything and raise an error if driver not ready
-        process = subprocess.Popen('nvidia-smi', shell=True, stdout=subprocess.PIPE,
-                                   stderr=subprocess.PIPE, executable="/bin/bash")
-        info, error = process.communicate()
-        if process.returncode != 0:
-            raise RuntimeError(f"Nvida drivers not ready. \n {error.decode('utf-8')}")
-        _logger.info("nvidia-smi command successful")
-
     def _run_pykilosort(self, ap_file):
         f"""
         Runs the ks2 matlab spike sorting for one probe dataset
@@ -132,18 +137,20 @@ class SpikeSorting(tasks.Task):
         session_path/spike_sorters/{self.SPIKE_SORTER_NAME}/probeXX folder
         :return: path of the folder containing ks2 spike sorting output
         """
-
+        self.version = self._fetch_pykilosort_version(self.PYKILOSORT_REPO)
         label = ap_file.parts[-2]  # this is usually the probe name
-        if ap_file.parent.joinpath(f"spike_sorting_{self.SPIKE_SORTER_NAME}.log").exists():
-            _logger.info(f"Already ran: spike_sorting_{self.SPIKE_SORTER_NAME}.log"
-                         f" found for {ap_file}, skipping.")
-            return ap_file.parent
-        sorter_dir = self.session_path.joinpath("spike_sorters", self.SPIKE_SORTER_NAME, label)
-        print(sorter_dir.joinpath(f"spike_sorting_{self.SPIKE_SORTER_NAME}.log"))
-        if sorter_dir.joinpath(f"spike_sorting_{self.SPIKE_SORTER_NAME}.log").exists():
-            _logger.info(f"Already ran: spike_sorting_{self.SPIKE_SORTER_NAME}.log"
-                         f" found in {sorter_dir}, skipping.")
-            return sorter_dir
+        FORCE_RERUN = True
+        if not FORCE_RERUN:
+            if ap_file.parent.joinpath(f"spike_sorting_{self.SPIKE_SORTER_NAME}.log").exists():
+                _logger.info(f"Already ran: spike_sorting_{self.SPIKE_SORTER_NAME}.log"
+                             f" found for {ap_file}, skipping.")
+                return ap_file.parent
+            sorter_dir = self.session_path.joinpath("spike_sorters", self.SPIKE_SORTER_NAME, label)
+            print(sorter_dir.joinpath(f"spike_sorting_{self.SPIKE_SORTER_NAME}.log"))
+            if sorter_dir.joinpath(f"spike_sorting_{self.SPIKE_SORTER_NAME}.log").exists():
+                _logger.info(f"Already ran: spike_sorting_{self.SPIKE_SORTER_NAME}.log"
+                             f" found in {sorter_dir}, skipping.")
+                return sorter_dir
         # get the scratch drive from the shell script
         with open(self.SHELL_SCRIPT) as fid:
             lines = fid.readlines()
@@ -164,7 +171,7 @@ class SpikeSorting(tasks.Task):
             shutil.rmtree(temp_dir, ignore_errors=True)
         temp_dir.mkdir(parents=True, exist_ok=True)
 
-        self._check_nvidia()
+        check_nvidia_driver()
         command2run = f"{self.SHELL_SCRIPT} {ap_file} {temp_dir}"
         _logger.info(command2run)
         process = subprocess.Popen(
@@ -189,7 +196,6 @@ class SpikeSorting(tasks.Task):
 
         shutil.copytree(temp_dir.joinpath('output'), sorter_dir, dirs_exist_ok=True)
         shutil.rmtree(temp_dir, ignore_errors=True)
-        self.version = self._fetch_ks2_commit_hash(self.PYKILOSORT_REPO)
         return sorter_dir
 
     def _run(self, overwrite=False):
@@ -207,7 +213,7 @@ class SpikeSorting(tasks.Task):
         for ap_file, label in ap_files:
             try:
                 ks2_dir = self._run_pykilosort(ap_file)  # runs ks2, skips if it already ran
-                probe_out_path = self.session_path.joinpath("alf", label)
+                probe_out_path = self.session_path.joinpath("alf", label, self.SPIKE_SORTER_NAME)
                 shutil.rmtree(probe_out_path, ignore_errors=True)
                 probe_out_path.mkdir(parents=True, exist_ok=True)
                 spikes.ks2_to_alf(
@@ -217,6 +223,10 @@ class SpikeSorting(tasks.Task):
                     bin_file=ap_file,
                     ampfactor=self._sample2v(ap_file),
                 )
+                logfile = ks2_dir.joinpath(f"spike_sorting_{self.SPIKE_SORTER_NAME}.log")
+                if logfile.exists():
+                    shutil.copyfile(logfile, probe_out_path.joinpath(
+                        f"_ibl_log.info_{self.SPIKE_SORTER_NAME}.log"))
                 out, _ = spikes.sync_spike_sorting(ap_file=ap_file, out_path=probe_out_path)
                 out_files.extend(out)
                 # convert ks2_output into tar file and also register
@@ -336,9 +346,11 @@ class EphysCellsQc(tasks.Task):
         :return:
         """
         eid = self.one.path2eid(self.session_path, query_type='remote')
-        pdict = self.one.alyx.rest('insertions', 'list',
-                                   session=eid, name=folder_probe.parts[-1], no_cache=True)
+        # the probe name is the first folder after alf: {session_path}/alf/{probe_name}/{spike_sorter_name}
+        probe_name = Path(folder_probe).relative_to(self.session_path.joinpath('alf')).parts[0]
+        pdict = self.one.alyx.rest('insertions', 'list', session=eid, name=probe_name, no_cache=True)
         if len(pdict) != 1:
+            _logger.warning(f'No probe found for probe name: {probe_name}')
             return
         isok = df_units['label'] == 1
         qcdict = {'n_units': int(df_units.shape[0]),
