@@ -2,23 +2,53 @@ import json
 import logging
 import shutil
 from pathlib import Path
+import re
+
+import iblutil.io.params as params
+from one.alf.spec import is_uuid_string, is_session_path
+from one.alf.files import get_session_path
+from one.api import ONE
 
-import alf.folders as folders
 import ibllib.io.flags as flags
-import ibllib.io.params as params
 import ibllib.io.raw_data_loaders as raw
 import ibllib.io.spikeglx as spikeglx
-from alf.io import is_uuid_string
-from oneibl.one import ONE
+from ibllib.io.misc import delete_empty_folders
 
 log = logging.getLogger("ibllib")
 
 
+def subjects_data_folder(folder: Path, rglob: bool = False) -> Path:
+    """Given a root_data_folder will try to find a 'Subjects' data folder.
+    If Subjects folder is passed will return it directly."""
+    if not isinstance(folder, Path):
+        folder = Path(folder)
+    if rglob:
+        func = folder.rglob
+    else:
+        func = folder.glob
+
+    # Try to find Subjects folder one level
+    if folder.name.lower() != 'subjects':
+        # Try to find Subjects folder if folder.glob
+        spath = [x for x in func('*') if x.name.lower() == 'subjects']
+        if not spath:
+            raise ValueError('No "Subjects" folder in children folders')
+        elif len(spath) > 1:
+            raise ValueError(f'Multiple "Subjects" folder in children folders: {spath}')
+        else:
+            folder = folder / spath[0]
+
+    return folder
+
+
 def cli_ask_default(prompt: str, default: str):
-    dflt = " [default: {}]: "
-    dflt = dflt.format(default)
-    ans = input(prompt + dflt) or default
-    return ans
+    """
+    Prompt the user for input, display the default option and return user input or default
+    :param prompt: String to display to user
+    :param default: The default value to return if user doesn't enter anything
+    :return: User input or default
+    """
+    return input(f'{prompt} [default: {default}]: ') or default
 
 
 def cli_ask_options(prompt: str, options: list, default_idx: int = 0) -> str:
@@ -32,7 +62,7 @@ def cli_ask_options(prompt: str, options: list, default_idx: int = 0) -> str:
     return ans
 
 
-def behavior_exists(session_path: str) -> bool:  # testOK
+def behavior_exists(session_path: str) -> bool:
     session_path = Path(session_path)
     behavior_path = session_path / "raw_behavior_data"
     if behavior_path.exists():
@@ -41,27 +71,38 @@ def behavior_exists(session_path: str) -> bool:  # testOK
 
 
 def check_transfer(src_session_path: str, dst_session_path: str):
-    # missing fail test
-    src_files = sorted([x for x in Path(src_session_path).rglob("*") if x.is_file()])
-    dst_files = sorted([x for x in Path(dst_session_path).rglob("*") if x.is_file()])
-    assert_msg = "src_files != dst_files"
-    assert len(src_files) == len(dst_files), assert_msg
+    """
+    Check all the files in the source directory match those in the destination directory.
+    :param src_session_path: The source directory that was copied
+    :param dst_session_path: The copy target directory
+    :return:
+    """
+    src_files = sorted([x for x in Path(src_session_path).rglob('*') if x.is_file()])
+    dst_files = sorted([x for x in Path(dst_session_path).rglob('*') if x.is_file()])
+    assert len(src_files) == len(dst_files), 'Not all files transferred'
     for s, d in zip(src_files, dst_files):
-        assert s.name == d.name, assert_msg
-        assert s.stat().st_size == d.stat().st_size, assert_msg
+        assert s.name == d.name, 'file name mismatch'
+        assert s.stat().st_size == d.stat().st_size, 'file size mismatch'
 
 
 def rename_session(session_path: str) -> Path:
-    session_path = Path(folders.session_path(session_path))
+    """
+    Rename a session.  Prompts the user for the new subject name, data and number then moves
+    session path to new session path.
+    :param session_path: A session path to rename
+    :return: The renamed session path
+    """
+    session_path = get_session_path(session_path)
     if session_path is None:
-        return
+        raise ValueError('Session path not valid ALF session folder')
     mouse = session_path.parts[-3]
     date = session_path.parts[-2]
     sess = session_path.parts[-1]
-    new_mouse = input(f"Please insert mouse NAME [current value: {mouse}]> ") or mouse
+    new_mouse = input(f"Please insert subject NAME [current value: {mouse}]> ") or mouse
     new_date = input(f"Please insert new session DATE [current value: {date}]> ") or date
     new_sess = input(f"Please insert new session NUMBER [current value: {sess}]> ") or sess
-    new_session_path = Path(*session_path.parts[:-3]) / new_mouse / new_date / new_sess
+    new_session_path = Path(*session_path.parts[:-3]) / new_mouse / new_date / new_sess.zfill(3)
+    assert is_session_path(new_session_path), 'invalid subject, date or number'
 
     shutil.move(str(session_path), str(new_session_path))
     print(session_path, "--> renamed to:")
@@ -147,8 +188,7 @@ def create_ephyspc_params(force=False, silent=False):
     if silent:
         data_folder_path = r"D:\iblrig_data\Subjects"
         remote_data_folder_path = r"\\iblserver.champalimaud.pt\ibldata\Subjects"
-        probe_type_00 = "3A"
-        probe_type_01 = "3B"
+        probe_types = {"PROBE_TYPE_00": "3A", "PROBE_TYPE_01": "3B"}
     else:
         data_folder_path = cli_ask_default(
             r"Where's your LOCAL 'Subjects' data folder?", r"D:\iblrig_data\Subjects"
@@ -157,13 +197,16 @@ def create_ephyspc_params(force=False, silent=False):
             r"Where's your REMOTE 'Subjects' data folder?",
             r"\\iblserver.champalimaud.pt\ibldata\Subjects",
         )
-        probe_type_00 = cli_ask_options("What's the type of PROBE 00?", ["3A", "3B"])
-        probe_type_01 = cli_ask_options("What's the type of PROBE 01?", ["3A", "3B"])
+        n_probes = int(cli_ask_default("How many probes are you using?", '2'))
+        assert 100 > n_probes > 0, 'Please enter number between 1, 99 inclusive'
+        probe_types = {}
+        for i in range(n_probes):
+            probe_types[f'PROBE_TYPE_{i:02}'] = cli_ask_options(
+                f"What's the type of PROBE {i:02}?", ["3A", "3B"])
     param_dict = {
         "DATA_FOLDER_PATH": data_folder_path,
         "REMOTE_DATA_FOLDER_PATH": remote_data_folder_path,
-        "PROBE_TYPE_00": probe_type_00,
-        "PROBE_TYPE_01": probe_type_01,
+        **probe_types
     }
     params.write("ephyspc_params", param_dict)
     print(f"Created {params.getfile('ephyspc_params')}")
@@ -181,8 +224,8 @@ def confirm_video_remote_folder(local_folder=False, remote_folder=False, force=F
     local_folder = Path(local_folder)
     remote_folder = Path(remote_folder)
     # Check for Subjects folder
-    local_folder = folders.subjects_data_folder(local_folder, rglob=True)
-    remote_folder = folders.subjects_data_folder(remote_folder, rglob=True)
+    local_folder = subjects_data_folder(local_folder, rglob=True)
+    remote_folder = subjects_data_folder(remote_folder, rglob=True)
 
     print("LOCAL:", local_folder)
     print("REMOTE:", remote_folder)
@@ -236,8 +279,8 @@ def confirm_ephys_remote_folder(
     local_folder = Path(local_folder)
     remote_folder = Path(remote_folder)
     # Check for Subjects folder
-    local_folder = folders.subjects_data_folder(local_folder, rglob=True)
-    remote_folder = folders.subjects_data_folder(remote_folder, rglob=True)
+    local_folder = subjects_data_folder(local_folder, rglob=True)
+    remote_folder = subjects_data_folder(remote_folder, rglob=True)
 
     print("LOCAL:", local_folder)
     print("REMOTE:", remote_folder)
@@ -311,11 +354,8 @@ def create_alyx_probe_insertions(
     labels: list = None,
 ):
     if one is None:
-        one = ONE()
-    if is_uuid_string(session_path):
-        eid = session_path
-    else:
-        eid = one.eid_from_path(session_path)
+        one = ONE(cache_rest=None)
+    eid = session_path if is_uuid_string(session_path) else one.eid_from_path(session_path)
     if eid is None:
         print("Session not found on Alyx: please create session before creating insertions")
     if model is None:
@@ -339,12 +379,11 @@ def create_alyx_probe_insertions(
     qc_dict.update({"extended_qc": {}})
 
     # create the dictionary
+    insertions = []
     for plabel in probe_labels:
         insdict = {"session": eid, "name": plabel, "model": pmodel, "json": qc_dict}
         # search for the corresponding insertion in Alyx
-        alyx_insertion = one.alyx.rest(
-            "insertions", "list", session=insdict["session"], name=insdict["name"]
-        )
+        alyx_insertion = one.alyx.get(f'/insertions?&session={eid}&name={plabel}', clobber=True)
         # if it doesn't exist, create it
         if len(alyx_insertion) == 0:
             alyx_insertion = one.alyx.rest("insertions", "create", data=insdict)
@@ -354,16 +393,21 @@ def create_alyx_probe_insertions(
                 alyx_insertion = one.alyx.rest("insertions", "update", id=iid, data=insdict)
             else:
                 alyx_insertion = alyx_insertion[0]
+        insertions.append(alyx_insertion)
+    return insertions
 
 
 def create_ephys_flags(session_folder: str):
+    """
+    Create flags for processing an ephys session.  Should be called after move_ephys_files
+    :param session_folder: A path to an ephys session
+    :return:
+    """
     session_path = Path(session_folder)
     flags.write_flag_file(session_path.joinpath("extract_ephys.flag"))
     flags.write_flag_file(session_path.joinpath("raw_ephys_qc.flag"))
-    probe00_path = session_path / "raw_ephys_data" / "probe00"
-    probe01_path = session_path / "raw_ephys_data" / "probe01"
-    flags.write_flag_file(probe00_path.joinpath("spike_sorting.flag"))
-    flags.write_flag_file(probe01_path.joinpath("spike_sorting.flag"))
+    for probe_path in session_path.joinpath('raw_ephys_data').glob('probe*'):
+        flags.write_flag_file(probe_path.joinpath("spike_sorting.flag"))
 
 
 def create_ephys_transfer_done_flag(session_folder: str) -> None:
@@ -386,7 +430,9 @@ def check_create_raw_session_flag(session_folder: str) -> None:
         return
 
     is_biased = True if "biased" in sett["PYBPOD_PROTOCOL"] else False
-    if video.exists() and is_biased:
+    is_training = True if "training" in sett["PYBPOD_PROTOCOL"] else False
+    is_habituation = True if "habituation" in sett["PYBPOD_PROTOCOL"] else False
+    if video.exists() and (is_biased or is_training or is_habituation):
         flags.write_flag_file(session_path.joinpath("raw_session.flag"))
         video.unlink()
     if video.exists() and ephys.exists():
@@ -422,53 +468,22 @@ def rename_ephys_files(session_folder: str) -> None:
         shutil.move(str(nidqf), str(nidqf.parent / new_filename))
 
 
-def get_new_filename(filename: str) -> str:  # testOK
+def get_new_filename(filename: str) -> str:
     """get_new_filename is system agnostic (3A, 3B1, 3B2).
     Gets an alyx compatible filename from any spikeglx ephys file.
 
     :param filename: Name of an ephys file
-    :type filename: str
     :return: New name for ephys file
-    :rtype: str
     """
     root = "_spikeglx_ephysData"
-    # gt = '_g0_t0' or 'error
-    gt = None
-    for g in range(10):
-        for t in range(10):
-            if f"_g{g}_t{t}" in filename:
-                gt = f"_g{g}_t{t}"
-    else:
-        if gt is None:
-            raise NotImplementedError(
-                f"Can not parse {filename} as an ephys file with gX_tY where"
-                f"XY are single digits"
-            )
-
-    # ext = 'bin' or 'meta'
-    if ".bin" in filename:
-        ext = "bin"
-    elif ".meta" in filename:
-        ext = "meta"
-
-    if ".nidq." in filename:
-        return ".".join([root + gt, "nidq", ext])
-
-    # probe = 'imec0' or 'imec1'
-    if ".imec0." in filename:
-        probe = "imec0"
-    elif ".imec1." in filename:
-        probe = "imec1"
-    elif ".imec." in filename:
-        probe = "imec"
-
-    # freq = 'ap' or 'lf'
-    if ".ap." in filename:
-        freq = "ap"
-    elif ".lf." in filename:
-        freq = "lf"
-
-    return ".".join([root + gt, probe, freq, ext])
+    parts = filename.split('.')
+    if len(parts) < 3:
+        raise ValueError(fr'unrecognized filename "{filename}"')
+    pattern = r'.*(?P<gt>_g\d+_t\d+)'
+    match = re.match(pattern, parts[0])
+    if not match:  # py 3.8
+        raise ValueError(fr'unrecognized filename "{filename}"')
+    return '.'.join([root + match.group(1), *parts[1:]])
 
 
 def move_ephys_files(session_folder: str) -> None:
@@ -484,64 +499,51 @@ def move_ephys_files(session_folder: str) -> None:
     session_path = Path(session_folder)
     raw_ephys_data_path = session_path / "raw_ephys_data"
 
-    probe00_path = raw_ephys_data_path / "probe00"
-    probe01_path = raw_ephys_data_path / "probe01"
-    # 3A system imec only
-    imec_files = session_path.rglob("*.imec.*")
+    imec_files = session_path.rglob("*.imec*")
     for imf in imec_files:
-        if "probe00" in str(imf):
-            shutil.move(str(imf), str(probe00_path / imf.name))
-        elif "probe01" in str(imf):
-            shutil.move(str(imf), str(probe01_path / imf.name))
-    # 3B system
-    imec0_files = session_path.rglob("*.imec0.*")
-    imec1_files = session_path.rglob("*.imec1.*")
-    nidq_files = session_path.rglob("*.nidq.*")
-    # All imec 0 in probe00 folder
-    for i0f in imec0_files:
-        shutil.move(str(i0f), str(probe00_path / i0f.name))
-    # All imec 1 in probe01 folder
-    for i1f in imec1_files:
-        shutil.move(str(i1f), str(probe01_path / i1f.name))
-    # NIDAq files
+        # For 3B system probe0x == imecx
+        probe_number = re.match(r'_spikeglx_ephysData_g\d_t\d.imec(\d+).*', imf.name)
+        if not probe_number:
+            # For 3A system imec files must be in a 'probexx' folder
+            probe_label = re.search(r'probe\d+', str(imf))
+            assert probe_label, f'Cannot assign probe number to file {imf}'
+            probe_label = probe_label.group()
+        else:
+            probe_number, = probe_number.groups()
+            probe_label = f'probe{probe_number.zfill(2)}'
+        raw_ephys_data_path.joinpath(probe_label).mkdir(exist_ok=True)
+        shutil.move(imf, raw_ephys_data_path.joinpath(probe_label, imf.name))
+
+    # NIDAq files (3B system only)
     nidq_files = session_path.rglob("*.nidq.*")
     for nidqf in nidq_files:
         shutil.move(str(nidqf), str(raw_ephys_data_path / nidqf.name))
     # Delete all empty folders recursively
-    from ibllib.io.misc import delete_empty_folders
-
     delete_empty_folders(raw_ephys_data_path, dry=False, recursive=True)
 
 
 def create_custom_ephys_wirings(iblscripts_folder: str):
     iblscripts_path = Path(iblscripts_folder)
     PARAMS = load_ephyspc_params()
-    if PARAMS["PROBE_TYPE_00"] != PARAMS["PROBE_TYPE_01"]:
-        print("Having different probe types not supported")
-        raise (NotImplementedError)
+    probe_set = set(v for k, v in PARAMS.items() if k.startswith('PROBE_TYPE'))
 
     params_path = iblscripts_path.parent / "iblscripts_params"
     params_path.mkdir(parents=True, exist_ok=True)
     wirings_path = iblscripts_path / "deploy" / "ephyspc" / "wirings"
-    if "3A" in PARAMS["PROBE_TYPE_00"]:
+    for k, v in PARAMS.items():
+        if not k.startswith('PROBE_TYPE_'):
+            continue
+        probe_label = f'probe{k[-2:]}'
+        if v not in ('3A', '3B'):
+            raise ValueError(f'Unsupported probe type "{v}"')
         shutil.copy(
-            str(wirings_path / "3A.wiring.json"), str(params_path / "3A_probe00.wiring.json")
+            wirings_path / f"{v}.wiring.json", params_path / f"{v}_{probe_label}.wiring.json"
         )
-        shutil.copy(
-            str(wirings_path / "3A.wiring.json"), str(params_path / "3A_probe01.wiring.json")
-        )
-        print(f"Created 3A.wiring.json in {params_path}")
-    if "3B" in PARAMS["PROBE_TYPE_00"]:
-        shutil.copy(
-            str(wirings_path / "3B.wiring.json"), str(params_path / "3B_probe00.wiring.json")
-        )
-        shutil.copy(
-            str(wirings_path / "3B.wiring.json"), str(params_path / "3B_probe01.wiring.json")
-        )
-        print(f"Created 3B.wiring.json in {params_path}")
-        shutil.copy(str(wirings_path / "nidq.wiring.json"), str(params_path / "nidq.wiring.json"))
+        print(f"Created {v}.wiring.json in {params_path} for {probe_label}")
+    if "3B" in probe_set:
+        shutil.copy(wirings_path / "nidq.wiring.json", params_path / "nidq.wiring.json")
         print(f"Created nidq.wiring.json in {params_path}")
-    print(f"\nYou can now modify your wirings files from folder {params_path}")
+    print(f"\nYou can now modify your wiring files from folder {params_path}")
 
 
 def get_iblscripts_folder():
@@ -553,27 +555,17 @@ def copy_wiring_files(session_folder, iblscripts_folder):
     PARAMS = load_ephyspc_params()
     if PARAMS["PROBE_TYPE_00"] != PARAMS["PROBE_TYPE_01"]:
         print("Having different probe types is not supported")
-        raise (NotImplementedError)
+        raise NotImplementedError()
     session_path = Path(session_folder)
     iblscripts_path = Path(iblscripts_folder)
     iblscripts_params_path = iblscripts_path.parent / "iblscripts_params"
     wirings_path = iblscripts_path / "deploy" / "ephyspc" / "wirings"
-    probe00_path = session_path / "raw_ephys_data" / "probe00"
-    probe01_path = session_path / "raw_ephys_data" / "probe01"
-    termination = ".wiring.json"
-    # Determine if custom wiring applies
-    custom = True if iblscripts_params_path.exists() else False
+    termination = '.wiring.json'
     # Determine system
     ephys_system = PARAMS["PROBE_TYPE_00"]
-    # Define where to get the files from
-    if custom:
-        src_wiring_path = iblscripts_params_path
-        probe00_wiring_file_path = src_wiring_path / f"{ephys_system}_probe00.wiring.json"
-        probe01_wiring_file_path = src_wiring_path / f"{ephys_system}_probe01.wiring.json"
-    else:
-        src_wiring_path = wirings_path
-        probe00_wiring_file_path = src_wiring_path / f"{ephys_system}.wiring.json"
-        probe01_wiring_file_path = src_wiring_path / f"{ephys_system}.wiring.json"
+    # Define where to get the files from (determine if custom wiring applies)
+    src_wiring_path = iblscripts_params_path if iblscripts_params_path.exists() else wirings_path
+    probe_wiring_file_path = src_wiring_path / f"{ephys_system}{termination}"
 
     if ephys_system == "3B":
         # Copy nidq file
@@ -581,13 +573,13 @@ def copy_wiring_files(session_folder, iblscripts_folder):
         for nidqf in nidq_files:
             nidq_wiring_name = ".".join(str(nidqf.name).split(".")[:-1]) + termination
             shutil.copy(
-                str(src_wiring_path / "nidq.wiring.json"),
+                str(src_wiring_path / f"nidq{termination}"),
                 str(session_path / "raw_ephys_data" / nidq_wiring_name),
             )
     # If system is either (3A OR 3B) copy a wiring file for each ap.bin file
     for binf in session_path.rglob("*.ap.bin"):
-        wiring_name = ".".join(str(binf.name).split(".")[:-2]) + termination
-        if "probe00" in str(binf):
-            shutil.copy(str(probe00_wiring_file_path), str(probe00_path / wiring_name))
-        if "probe01" in str(binf):
-            shutil.copy(str(probe01_wiring_file_path), str(probe01_path / wiring_name))
+        probe_label = re.search(r'probe\d+', str(binf))
+        if probe_label:
+            wiring_name = ".".join(str(binf.name).split(".")[:-2]) + termination
+            dst_path = session_path / "raw_ephys_data" / probe_label.group() / wiring_name
+            shutil.copy(probe_wiring_file_path, dst_path)
