@@ -262,7 +262,6 @@ class TestWheelMovesExtraction(unittest.TestCase):
         test_data = self.test_data[1]
         wheel_moves = ephys_fpga.extract_wheel_moves(test_data[0][0], test_data[0][1])
         first, is_final, ind = extract_first_movement_times(wheel_moves, self.trials)
-
         np.testing.assert_allclose(first, [162.48462599, 105.62562599, np.nan])
         np.testing.assert_array_equal(is_final, [False, True, False])
         np.testing.assert_array_equal(ind, [46, 18])
@@ -270,6 +269,104 @@ class TestWheelMovesExtraction(unittest.TestCase):
 
 class TestEphysFPGA_TTLsExtraction(unittest.TestCase):
 
+    def test_audio_ttl_wiring_camera(self):
+        """
+        Test removal of spurious TTLs due to a wrong wiring of the camera onto the soundcard
+        example eid: e349a2e7-50a3-47ca-bc45-20d1899854ec
+        """
+        # on this example it's business as usual and the clean up should not change anything
+        audio = {
+            'times': np.array([1740.1032, 1740.20176667, 1741.0786, 1741.57713333, 1744.78716667, 1744.88573333]),
+            'polarities': np.array([1., -1., 1., -1., 1., -1.]),
+        }
+        audio_ = ephys_fpga._clean_audio(audio)
+        self.assertEqual(audio, audio_)
+        # on that example
+        audio = {'times': np.array([3399.4090251, 3399.4110249, 3399.4156911, 3399.4176909,
+                                    3399.42232377, 3399.42432357, 3399.42898977, 3399.43095624,
+                                    3399.43562244, 3399.43762224, 3399.44228844, 3399.44425491,
+                                    3399.44892111, 3399.45092091, 3399.45558711, 3399.45755358,
+                                    3399.46221978, 3399.46421958, 3399.46888578, 3399.47085225,
+                                    3399.47551845, 3399.47751825, 3399.48215112, 3399.48415092,
+                                    3399.48881712, 3399.49081692, 3399.49544979, 3399.49744959,
+                                    3399.50211579, 3399.50411559, 3400.306602, 3400.3086018,
+                                    3400.313268, 3400.3152678, 3400.31990067, 3400.32190047,
+                                    3400.32656667, 3400.32856647, 3400.33319934, 3400.33519914,
+                                    3400.33986534, 3400.34186514, 3400.34649801, 3400.34849781,
+                                    3400.35316401, 3400.35516381, 3400.35979668, 3400.36179648,
+                                    3400.36646268, 3400.36846248, 3400.37309535, 3400.37509515,
+                                    3400.37976135, 3400.38172782, 3400.38639402, 3400.38839382,
+                                    3400.39306002, 3400.39502649, 3400.39969269, 3400.40169249,
+                                    3400.40635869, 3400.40832516, 3400.41299136, 3400.41499116,
+                                    3400.41962403, 3400.42162383, 3400.42629003, 3400.42828983,
+                                    3400.4329227, 3400.4349225, 3400.4395887, 3400.4415885,
+                                    3400.44622137, 3400.44822117, 3400.45288737, 3400.45488717,
+                                    3400.45952004, 3400.46151984, 3400.46618604, 3400.46818584,
+                                    3400.47281871, 3400.47481851, 3400.47948471, 3400.48148451,
+                                    3400.48611738, 3400.48811718, 3400.49278338, 3400.49478318,
+                                    3400.49941605, 3400.50141585, 3400.50608205, 3400.50808185,
+                                    3400.51271472, 3400.51471452, 3400.51938072, 3400.52138052,
+                                    3400.52601339, 3400.52801319, 3400.53267939, 3400.53467919,
+                                    3400.53931206, 3400.54131186, 3400.54597806, 3400.54797786,
+                                    3400.55261073, 3400.55461053, 3400.55927673, 3400.5612432,
+                                    3400.5659094, 3400.5679092, 3400.5725754, 3400.57454187,
+                                    3400.57920807, 3400.58120787, 3400.58587407, 3400.58784054,
+                                    3400.59250674, 3400.59450654, 3400.59917274, 3400.60113921,
+                                    3400.60580541, 3400.60780521, 3400.61243808, 3400.61443788,
+                                    3400.61910408, 3400.62110388, 3400.62573675, 3400.62773655,
+                                    3400.63240275, 3400.63440255, 3400.63903542, 3400.64103522,
+                                    3400.64570142, 3400.64770122, 3400.65233409, 3400.65433389,
+                                    3400.65900009, 3400.66099989, 3400.66563276, 3400.66763256,
+                                    3400.67229876, 3400.67429856, 3400.67893143, 3400.68093123,
+                                    3400.68559743, 3400.68759723, 3400.6922301, 3400.6942299,
+                                    3400.6988961, 3400.7008959, 3400.70552877, 3400.70752857,
+                                    3400.71219477, 3400.71419457, 3400.71882744, 3400.72082724,
+                                    3400.72549344, 3400.72749324, 3400.73212611, 3400.73412591,
+                                    3400.73879211, 3400.74079191, 3400.74542478, 3400.74742458,
+                                    3400.75209078, 3400.75405725, 3400.75872345, 3400.76072325,
+                                    3400.76538945, 3400.76735592, 3400.77202212, 3400.77402192,
+                                    3400.77868812, 3400.78065459, 3400.78532079, 3400.78732059,
+                                    3400.79198679, 3400.79395326, 3400.79861946, 3400.80061926]),
+                 'polarities': np.array([1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1.,
+                                         -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1.,
+                                         1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1.,
+                                         -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1.,
+                                         1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1.,
+                                         -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1.,
+                                         1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1.,
+                                         -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1.,
+                                         1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1.,
+                                         -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1.,
+                                         1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1.,
+                                         -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1.,
+                                         1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1., 1.,
+                                         -1., 1., -1., 1., -1., 1., -1., 1., -1., 1., -1.])
+                 }
+        audio_ = ephys_fpga._clean_audio(audio)
+        expected = {'times': np.array([3399.4090251, 3399.50411559, 3400.306602, 3400.80061926]),
+                    'polarities': np.array([1., -1., 1., -1.])}
+        assert all([np.all(audio_[k] == expected[k]) for k in audio_])
+
+    def test_audio_ttl_start_up_down(self):
+        """
+        If the behaviour starts before FPGA, it is very unlikely but possible that the FPGA
+        starts on up state and that the first front of the audio is a downgoing one.
+        The extraction should handle both cases seamlessly: cf eid d839491f-55d8-4cbe-a298-7839208ba12b
+        """
+
+        def _test_audio(audio):
+            ready, error = ephys_fpga._assign_events_audio(audio['times'], audio['polarities'])
+            assert np.all(ready == audio['times'][audio['ready_tone']])
+            assert np.all(error == audio['times'][audio['error_tone']])
+        audio = {
+            'times': np.array([1740.1032, 1740.20176667, 1741.0786, 1741.57713333, 1744.78716667, 1744.88573333]),
+            'polarities': np.array([1., -1., 1., -1., 1., -1.]),
+            'error_tone': np.array([False, False, True, False, False, False]),
+            'ready_tone': np.array([True, False, False, False, True, False])
+        }
+        _test_audio(audio)  # this tests the usual pulses
+        _test_audio({k: audio[k][1:] for k in audio})  # this tests when it starts in upstate
+
     def test_ttl_bpod_gaelle_writes_protocols_but_guido_doesnt_read_them(self):
         bpod_t = np.array([5.423290950005423, 6.397993470006398, 6.468919710006469,
                            7.497916800007498, 7.997933460007998, 8.599239990008599,
