@@ -8,7 +8,7 @@ from pathlib import Path
 import numpy as np
 import pandas as pd
 
-import alf.io
+import one.alf.io as alfio
 from ibllib.io.extractors import training_trials, biased_trials, camera
 from ibllib.io import raw_data_loaders as raw
 from ibllib.io.extractors.base import BaseExtractor
@@ -270,23 +270,23 @@ class TestExtractTrialData(unittest.TestCase):
 
     def test_get_stimOn_times_lt5(self):
         # TRAINING SESSIONS
-        st = training_trials.StimOnTimes(
+        st = training_trials.StimOnTimes_deprecated(
             self.training_lt5['path']).extract()[0]
         self.assertTrue(isinstance(st, np.ndarray))
 
         # BIASED SESSIONS
-        st = biased_trials.StimOnTimes(
+        st = biased_trials.StimOnTimes_deprecated(
             self.biased_lt5['path']).extract()[0]
         self.assertTrue(isinstance(st, np.ndarray))
 
     def test_get_stimOn_times_ge5(self):
         # TRAINING SESSIONS
-        st = training_trials.StimOnTimes(
+        st = training_trials.StimOnTimes_deprecated(
             self.training_ge5['path']).extract()[0]
         self.assertTrue(isinstance(st, np.ndarray))
 
         # BIASED SESSIONS
-        st = biased_trials.StimOnTimes(
+        st = biased_trials.StimOnTimes_deprecated(
             self.biased_ge5['path']).extract()[0]
         self.assertTrue(isinstance(st, np.ndarray))
 
@@ -311,33 +311,6 @@ class TestExtractTrialData(unittest.TestCase):
             self.biased_ge5['path']).extract()[0]
         self.assertTrue(isinstance(st[0], np.ndarray))
 
-    @unittest.skip("not there yet")
-    def test_stimOn_extractor_values(self):
-        # Training lt5
-        st_old = training_trials.StimOnTimes(
-            self.training_lt5['path']).extract()[0]
-        st_new = training_trials.StimOnOffFreezeTimes(
-            self.training_lt5['path']).extract()[0]
-        self.assertTrue(np.all(st_old == st_new[0]))
-        # Training ge5
-        st_old = training_trials.StimOnTimes(
-            self.training_ge5['path']).extract()[0]
-        st_new = training_trials.StimOnOffFreezeTimes(
-            self.training_ge5['path']).extract()[0]
-        self.assertTrue(np.all(st_old == st_new[0]))
-        # Biased lt5
-        st_old = biased_trials.StimOnTimes(
-            self.biased_lt5['path']).extract()[0]
-        st_new = biased_trials.StimOnOffFreezeTimes(
-            self.biased_lt5['path']).extract()[0]
-        self.assertTrue(np.all(st_old == st_new[0]))
-        # Biased ge5
-        st_old = biased_trials.StimOnTimes(
-            self.biased_ge5['path']).extract()[0]
-        st_new = biased_trials.StimOnOffFreezeTimes(
-            self.biased_ge5['path']).extract()[0]
-        self.assertTrue(np.all(st_old == st_new[0]))
-
     def test_get_intervals(self):
         # TRAINING SESSIONS
         di = training_trials.Intervals(
@@ -554,14 +527,14 @@ class TestExtractTrialData(unittest.TestCase):
         # check the output dimensions
         from ibllib.io.extractors.bpod_trials import extract_all
         extract_all(self.training_ge5['path'])
-        trials = alf.io.load_object(self.training_ge5['path'] / 'alf', object='trials')
-        self.assertTrue(alf.io.check_dimensions(trials) == 0)
+        trials = alfio.load_object(self.training_ge5['path'] / 'alf', object='trials')
+        self.assertTrue(alfio.check_dimensions(trials) == 0)
         extract_all(self.training_lt5['path'])
-        trials = alf.io.load_object(self.training_lt5['path'] / 'alf', object='trials')
-        self.assertTrue(alf.io.check_dimensions(trials) == 0)
+        trials = alfio.load_object(self.training_lt5['path'] / 'alf', object='trials')
+        self.assertTrue(alfio.check_dimensions(trials) == 0)
         extract_all(self.biased_ge5['path'])
-        trials = alf.io.load_object(self.biased_ge5['path'] / 'alf', object='trials')
-        self.assertTrue(alf.io.check_dimensions(trials) == 0)
+        trials = alfio.load_object(self.biased_ge5['path'] / 'alf', object='trials')
+        self.assertTrue(alfio.check_dimensions(trials) == 0)
         # Wheel moves extraction fails for these wheel data; skipping
         # extract_training(self.biased_lt5['path'])
         # trials = alf.io.load_object(self.biased_lt5['path'] / 'alf', object='_ibl_trials')
