@@ -1,9 +1,13 @@
 import unittest
 from pathlib import Path
+import re
+from inspect import getmembers, ismethod
+
 import numpy as np
 import copy
 
-from oneibl.one import ONE
+from one.api import ONE
+from ibllib.tests import TEST_DB
 from ibllib.atlas import AllenAtlas
 from ibllib.pipes.misc import create_alyx_probe_insertions
 from ibllib.qc.alignment_qc import AlignmentQC
@@ -11,8 +15,7 @@ from ibllib.pipes.histology import register_track
 
 
 EPHYS_SESSION = 'b1c968ad-4874-468d-b2e4-5ffa9b9964e9'
-one = ONE(username='test_user', password='TapetesBloc18',
-          base_url='https://test.alyx.internationalbrainlab.org')
+one = ONE(**TEST_DB)
 brain_atlas = AllenAtlas(25)
 
 
@@ -22,7 +25,7 @@ class TestProbeInsertion(unittest.TestCase):
         probe = ['probe00', 'probe01']
         create_alyx_probe_insertions(session_path=EPHYS_SESSION, model='3B2', labels=probe,
                                      one=one, force=True)
-        insertion = one.alyx.rest('insertions', 'list', session=EPHYS_SESSION)
+        insertion = one.alyx.get(f'/insertions?&session={EPHYS_SESSION}', clobber=True)
         assert(len(insertion) == 2)
         assert (insertion[0]['json']['qc'] == 'NOT_SET')
         assert (len(insertion[0]['json']['extended_qc']) == 0)
@@ -31,26 +34,16 @@ class TestProbeInsertion(unittest.TestCase):
         one.alyx.rest('insertions', 'delete', id=insertion[1]['id'])
 
 
-class TestHistologyQc(unittest.TestCase):
-
-    def test_session_creation(self):
-        pass
-
-    def test_probe_qc(self):
-        pass
-
-
 class TestTracingQc(unittest.TestCase):
+    probe01_id = None
+    probe00_id = None
 
     @classmethod
     def setUpClass(cls) -> None:
         probe = ['probe00', 'probe01']
-        create_alyx_probe_insertions(session_path=EPHYS_SESSION, model='3B2', labels=probe,
-                                     one=one, force=True)
-        cls.probe00_id = one.alyx.rest('insertions', 'list', session=EPHYS_SESSION,
-                                       name='probe00')[0]['id']
-        cls.probe01_id = one.alyx.rest('insertions', 'list', session=EPHYS_SESSION,
-                                       name='probe01')[0]['id']
+        ins = create_alyx_probe_insertions(session_path=EPHYS_SESSION, model='3B2', labels=probe,
+                                           one=one, force=True)
+        cls.probe00_id, cls.probe01_id = (x['id'] for x in ins)
         data = np.load(Path(Path(__file__).parent.parent.
                             joinpath('fixtures', 'qc', 'data_alignmentqc_existing.npz')),
                        allow_pickle=True)
@@ -59,7 +52,7 @@ class TestTracingQc(unittest.TestCase):
     def test_tracing_exists(self):
         register_track(self.probe00_id, picks=self.xyz_picks, one=one, overwrite=True,
                        channels=False)
-        insertion = one.alyx.rest('insertions', 'read', id=self.probe00_id)
+        insertion = one.alyx.get('/insertions/' + self.probe00_id, clobber=True)
 
         assert (insertion['json']['qc'] == 'NOT_SET')
         assert (insertion['json']['extended_qc']['tracing_exists'] == 1)
@@ -67,7 +60,7 @@ class TestTracingQc(unittest.TestCase):
     def test_tracing_not_exists(self):
         register_track(self.probe01_id, picks=None, one=one, overwrite=True,
                        channels=False)
-        insertion = one.alyx.rest('insertions', 'read', id=self.probe01_id)
+        insertion = one.alyx.get('/insertions/' + self.probe01_id, clobber=True)
         assert (insertion['json']['qc'] == 'CRITICAL')
         assert (insertion['json']['extended_qc']['tracing_exists'] == 0)
 
@@ -78,6 +71,8 @@ class TestTracingQc(unittest.TestCase):
 
 
 class TestAlignmentQcExisting(unittest.TestCase):
+    probe_id = None
+    prev_traj_id = None
 
     @classmethod
     def setUpClass(cls) -> None:
@@ -97,20 +92,28 @@ class TestAlignmentQcExisting(unittest.TestCase):
         cls.trajectory = data['trajectory'].tolist()
         cls.trajectory.update({'probe_insertion': cls.probe_id})
 
-    def setUp(self):
-        traj = one.alyx.rest('trajectories', 'list', probe_id=self.probe_id,
-                             provenance='Ephys aligned histology track')
+    def test_alignments(self):
+        checks = getmembers(self, lambda x: ismethod(x) and re.match(r'^_\d{2}_.*', x.__name__))
+        # Run numbered functions in order
+        for _, fn in sorted(checks, key=lambda x: x[0]):
+            self._get_prev_traj_id()
+            fn()
+
+    def _get_prev_traj_id(self):
+        traj = one.alyx.get('/trajectories?'
+                            f'&probe_id={self.probe_id}'
+                            '&provenance=Ephys aligned histology track', clobber=True)
         if traj:
             self.prev_traj_id = traj[0]['id']
 
-    def test_01_no_alignments(self):
+    def _01_no_alignments(self):
         align_qc = AlignmentQC(self.probe_id, one=one, brain_atlas=brain_atlas, channels=False)
         align_qc.run(update=True, upload_alyx=True, upload_flatiron=False)
-        insertion = one.alyx.rest('insertions', 'read', id=self.probe_id)
-        assert (insertion['json']['qc'] == 'NOT_SET')
-        assert (len(insertion['json']['extended_qc']) == 0)
+        insertion = one.alyx.get(f'/insertions/{self.probe_id}', clobber=True)
+        self.assertEqual('NOT_SET', insertion['json']['qc'])
+        self.assertTrue(len(insertion['json']['extended_qc']) == 0)
 
-    def test_02_one_alignment(self):
+    def _02_one_alignment(self):
         alignments = {'2020-06-26T16:40:14_Karolina_Socha':
                       self.alignments['2020-06-26T16:40:14_Karolina_Socha']}
         trajectory = copy.deepcopy(self.trajectory)
@@ -118,39 +121,28 @@ class TestAlignmentQcExisting(unittest.TestCase):
         _ = one.alyx.rest('trajectories', 'create', data=trajectory)
         align_qc = AlignmentQC(self.probe_id, one=one, brain_atlas=brain_atlas, channels=False)
         align_qc.run(update=True, upload_alyx=True, upload_flatiron=False)
-        insertion = one.alyx.rest('insertions', 'read', id=self.probe_id)
-        assert (insertion['json']['qc'] == 'NOT_SET')
-        assert (insertion['json']['extended_qc']['alignment_count'] == 1)
-        assert (insertion['json']['extended_qc']['alignment_stored'] ==
-                '2020-06-26T16:40:14_Karolina_Socha')
-        assert (insertion['json']['extended_qc']['alignment_resolved'] == 0)
+        _verify(self,
+                alignment_count=1,
+                alignment_stored='2020-06-26T16:40:14_Karolina_Socha',
+                alignment_resolved=False)
 
-    def test_03_alignments_disagree(self):
+    def _03_alignments_disagree(self):
         alignments = {'2020-06-26T16:40:14_Karolina_Socha':
                       self.alignments['2020-06-26T16:40:14_Karolina_Socha'],
                       '2020-06-12T00:39:15_nate': self.alignments['2020-06-12T00:39:15_nate']}
         trajectory = copy.deepcopy(self.trajectory)
         trajectory.update({'json': alignments})
         traj = one.alyx.rest('trajectories', 'update', id=self.prev_traj_id, data=trajectory)
-        traj_id = traj['id']
         align_qc = AlignmentQC(self.probe_id, one=one, brain_atlas=brain_atlas, channels=False)
-        insertion = one.alyx.rest('insertions', 'read', id=self.probe_id)
         align_qc.load_data(prev_alignments=traj['json'], xyz_picks=np.array(self.xyz_picks) / 1e6,
                            cluster_chns=self.cluster_chns)
         align_qc.run(update=True, upload_alyx=True, upload_flatiron=False)
-        insertion = one.alyx.rest('insertions', 'read', id=self.probe_id)
-        assert (insertion['json']['qc'] == 'NOT_SET')
-        assert (insertion['json']['extended_qc']['alignment_count'] == 2)
-        assert (insertion['json']['extended_qc']['alignment_stored'] ==
-                '2020-06-26T16:40:14_Karolina_Socha')
-        assert (insertion['json']['extended_qc']['alignment_resolved'] == 0)
-        assert (insertion['json']['extended_qc']['alignment_qc'] < 0.8)
-        assert (np.isclose(insertion['json']['extended_qc']['alignment_qc'], 0.782216))
-        traj = one.alyx.rest('trajectories', 'list', probe_id=self.probe_id,
-                             provenance='Ephys aligned histology track')
-        assert(traj_id == traj[0]['id'])
 
-    def test_04_alignments_agree(self):
+        _verify(self, alignment_qc=0.782216, alignment_resolved=False,
+                alignment_count=2, alignment_stored='2020-06-26T16:40:14_Karolina_Socha',
+                trajectory_created=False)
+
+    def _04_alignments_agree(self):
         alignments = {'2020-06-19T10:52:36_noam.roth':
                       self.alignments['2020-06-19T10:52:36_noam.roth'],
                       '2020-06-12T00:39:15_nate': self.alignments['2020-06-12T00:39:15_nate']}
@@ -161,42 +153,24 @@ class TestAlignmentQcExisting(unittest.TestCase):
         align_qc = AlignmentQC(self.probe_id, one=one, brain_atlas=brain_atlas, channels=False)
         align_qc.load_data(cluster_chns=self.cluster_chns)
         align_qc.run(update=True, upload_alyx=True, upload_flatiron=False)
-        insertion = one.alyx.rest('insertions', 'read', id=self.probe_id)
-        assert (insertion['json']['qc'] == 'NOT_SET')
-        assert (insertion['json']['extended_qc']['alignment_count'] == 2)
-        assert (insertion['json']['extended_qc']['alignment_stored'] ==
-                '2020-06-19T10:52:36_noam.roth')
-        assert (insertion['json']['extended_qc']['alignment_resolved'] == 1)
-        assert (insertion['json']['extended_qc']['alignment_resolved_by'] == 'qc')
-        assert (insertion['json']['extended_qc']['alignment_qc'] > 0.8)
-        assert (np.isclose(insertion['json']['extended_qc']['alignment_qc'], 0.952319))
-        traj = one.alyx.rest('trajectories', 'list', probe_id=self.probe_id,
-                             provenance='Ephys aligned histology track')
-        assert(self.prev_traj_id == traj[0]['id'])
 
-    def test_05_not_latest_alignments_agree(self):
+        _verify(self, alignment_resolved='qc', alignment_qc=0.952319, trajectory_created=False,
+                alignment_count=2, alignment_stored='2020-06-19T10:52:36_noam.roth')
+
+    def _05_not_latest_alignments_agree(self):
         alignments = copy.deepcopy(self.alignments)
         trajectory = copy.deepcopy(self.trajectory)
         trajectory.update({'json': alignments})
         traj = one.alyx.rest('trajectories', 'update', id=self.prev_traj_id, data=trajectory)
-        assert(self.prev_traj_id == traj['id'])
+        self.assertEqual(self.prev_traj_id, traj['id'])
         align_qc = AlignmentQC(self.probe_id, one=one, brain_atlas=brain_atlas, channels=False)
         align_qc.load_data(prev_alignments=traj['json'], xyz_picks=np.array(self.xyz_picks) / 1e6,
                            cluster_chns=self.cluster_chns)
         align_qc.resolved = 0
         align_qc.run(update=True, upload_alyx=True, upload_flatiron=False)
-        insertion = one.alyx.rest('insertions', 'read', id=self.probe_id)
-        assert (insertion['json']['qc'] == 'NOT_SET')
-        assert (insertion['json']['extended_qc']['alignment_count'] == 4)
-        assert (insertion['json']['extended_qc']['alignment_stored'] ==
-                '2020-06-19T10:52:36_noam.roth')
-        assert (insertion['json']['extended_qc']['alignment_resolved'] == 1)
-        assert (insertion['json']['extended_qc']['alignment_resolved_by'] == 'qc')
-        assert (insertion['json']['extended_qc']['alignment_qc'] > 0.8)
-        assert (np.isclose(insertion['json']['extended_qc']['alignment_qc'], 0.952319))
-        traj = one.alyx.rest('trajectories', 'list', probe_id=self.probe_id,
-                             provenance='Ephys aligned histology track')
-        assert(self.prev_traj_id != traj[0]['id'])
+
+        _verify(self, alignment_resolved='qc', alignment_qc=0.952319, alignment_count=4,
+                alignment_stored='2020-06-19T10:52:36_noam.roth', trajectory_created=True)
 
     @classmethod
     def tearDownClass(cls) -> None:
@@ -204,6 +178,9 @@ class TestAlignmentQcExisting(unittest.TestCase):
 
 
 class TestAlignmentQcManual(unittest.TestCase):
+    probe_id = None
+    prev_traj_id = None
+
     @classmethod
     def setUpClass(cls) -> None:
         data = np.load(Path(Path(__file__).parent.parent.
@@ -225,77 +202,107 @@ class TestAlignmentQcManual(unittest.TestCase):
         cls.trajectory.update({'json': cls.alignments})
         cls.traj = one.alyx.rest('trajectories', 'create', data=cls.trajectory)
 
-    def setUp(self) -> None:
-        traj = one.alyx.rest('trajectories', 'list', probe_id=self.probe_id,
-                             provenance='Ephys aligned histology track')
+    def test_alignments(self):
+        checks = getmembers(self, lambda x: ismethod(x) and re.match(r'^_\d{2}_.*', x.__name__))
+        # Run numbered functions in order
+        for _, fn in sorted(checks, key=lambda x: x[0]):
+            self._get_prev_traj_id()
+            fn()
+
+    def _get_prev_traj_id(self):
+        traj = one.alyx.get('/trajectories?'
+                            f'&probe_id={self.probe_id}'
+                            '&provenance=Ephys aligned histology track', clobber=True)
         if traj:
             self.prev_traj_id = traj[0]['id']
 
-    def test_01_normal_computation(self):
+    def _01_normal_computation(self):
         align_qc = AlignmentQC(self.probe_id, one=one, brain_atlas=brain_atlas, channels=False)
         align_qc.load_data(prev_alignments=self.traj['json'],
                            xyz_picks=np.array(self.xyz_picks) / 1e6,
                            cluster_chns=self.cluster_chns)
         align_qc.run(update=True, upload_alyx=True, upload_flatiron=False)
-        insertion = one.alyx.rest('insertions', 'read', id=self.probe_id)
-        assert (insertion['json']['qc'] == 'NOT_SET')
-        assert (insertion['json']['extended_qc']['alignment_count'] == 3)
-        assert (insertion['json']['extended_qc']['alignment_stored'] ==
-                '2020-09-28T15:57:25_mayo')
-        assert (insertion['json']['extended_qc']['alignment_resolved'] == 0)
-        assert (insertion['json']['extended_qc']['alignment_qc'] < 0.8)
-        assert (np.isclose(insertion['json']['extended_qc']['alignment_qc'], 0.604081))
-        traj = one.alyx.rest('trajectories', 'list', probe_id=self.probe_id,
-                             provenance='Ephys aligned histology track')
-        assert(self.prev_traj_id == traj[0]['id'])
+        _verify(self,
+                alignment_resolved=False,
+                alignment_stored='2020-09-28T15:57:25_mayo',
+                alignment_count=3,
+                trajectory_created=False,
+                alignment_qc=0.604081)
 
-    def test_02_manual_resolution_latest(self):
+    def _02_manual_resolution_latest(self):
         align_qc = AlignmentQC(self.probe_id, one=one, brain_atlas=brain_atlas, channels=False)
         align_qc.load_data(prev_alignments=self.traj['json'],
                            xyz_picks=np.array(self.xyz_picks) / 1e6,
                            cluster_chns=self.cluster_chns)
         align_qc.resolve_manual('2020-09-28T15:57:25_mayo', update=True, upload_alyx=True,
                                 upload_flatiron=False)
-        insertion = one.alyx.rest('insertions', 'read', id=self.probe_id)
-        assert (insertion['json']['qc'] == 'NOT_SET')
-        assert (insertion['json']['extended_qc']['alignment_count'] == 3)
-        assert (insertion['json']['extended_qc']['alignment_stored'] ==
-                '2020-09-28T15:57:25_mayo')
-        assert (insertion['json']['extended_qc']['alignment_resolved'] == 1)
-        assert (insertion['json']['extended_qc']['alignment_resolved_by'] == 'experimenter')
-        assert (insertion['json']['extended_qc']['alignment_qc'] < 0.8)
-        assert (np.isclose(insertion['json']['extended_qc']['alignment_qc'], 0.604081))
-        traj = one.alyx.rest('trajectories', 'list', probe_id=self.probe_id,
-                             provenance='Ephys aligned histology track')
-        assert(self.prev_traj_id == traj[0]['id'])
+        _verify(self,
+                alignment_resolved='experimenter',
+                alignment_stored='2020-09-28T15:57:25_mayo',
+                alignment_count=3,
+                trajectory_created=False,
+                alignment_qc=0.604081)
 
-    def test_03_manual_resolution_not_latest(self):
+    def _03_manual_resolution_not_latest(self):
         align_qc = AlignmentQC(self.probe_id, one=one, brain_atlas=brain_atlas, channels=False)
         align_qc.load_data(prev_alignments=self.traj['json'],
                            xyz_picks=np.array(self.xyz_picks) / 1e6,
                            cluster_chns=self.cluster_chns)
         align_qc.resolve_manual('2020-09-28T10:03:06_alejandro', update=True, upload_alyx=True,
                                 upload_flatiron=False, force=True)
-        insertion = one.alyx.rest('insertions', 'read', id=self.probe_id)
-        assert (insertion['json']['qc'] == 'NOT_SET')
-        assert (insertion['json']['extended_qc']['alignment_count'] == 3)
-        assert (insertion['json']['extended_qc']['alignment_stored'] ==
-                '2020-09-28T10:03:06_alejandro')
-        assert (insertion['json']['extended_qc']['alignment_resolved'] == 1)
-        assert (insertion['json']['extended_qc']['alignment_resolved_by'] == 'experimenter')
-        assert (insertion['json']['extended_qc']['alignment_qc'] < 0.8)
-        assert (np.isclose(insertion['json']['extended_qc']['alignment_qc'], 0.604081))
-
-        traj = one.alyx.rest('trajectories', 'list', probe_id=self.probe_id,
-                             provenance='Ephys aligned histology track')
-        assert(self.prev_traj_id != traj[0]['id'])
+        _verify(self,
+                alignment_resolved='experimenter',
+                alignment_stored='2020-09-28T10:03:06_alejandro',
+                alignment_count=3,
+                trajectory_created=True,
+                alignment_qc=0.604081)
 
     @classmethod
     def tearDownClass(cls) -> None:
         one.alyx.rest('insertions', 'delete', id=cls.probe_id)
 
 
+def _verify(tc, alignment_resolved=None, alignment_count=None,
+            alignment_stored=None, trajectory_created=False, alignment_qc=None):
+    """
+    For a given test case with a `probe_id` attribute, check that Alyx returns insertion records
+    that match the provided parameters.
+    :param tc: An instance of TestAlignmentQcManual or TestAlignmentQcExisting
+    :param alignment_resolved: Check the alignment_resolved is true or false
+    :param alignment_count: Check the alignment count matches the one given
+    :param alignment_stored: Check the alignment stored key matches the one given
+    :param trajectory_created: Check whether a new trajectory exists on Alyx
+    :param alignment_qc: Check the stored QC value is close to the provided one
+    :return:
+    """
+    QC_THRESH = 0.8  # Expected alignment QC threshold
+    insertion = one.alyx.get(f'/insertions/{tc.probe_id}', clobber=True)
+    tc.assertEqual('NOT_SET', insertion['json']['qc'])
+    if alignment_count is not None:
+        tc.assertEqual(alignment_count, insertion['json']['extended_qc']['alignment_count'])
+    if alignment_stored is not None:
+        tc.assertEqual(alignment_stored,
+                       insertion['json']['extended_qc']['alignment_stored'])
+    if alignment_resolved:
+        tc.assertEqual(alignment_resolved,
+                       insertion['json']['extended_qc']['alignment_resolved_by'])
+        tc.assertEqual(1, insertion['json']['extended_qc']['alignment_resolved'])
+    elif alignment_resolved is False:
+        tc.assertEqual(0, insertion['json']['extended_qc']['alignment_resolved'])
+    if alignment_qc:
+        tc.assertEqual(insertion['json']['extended_qc']['alignment_qc'] < QC_THRESH,
+                       alignment_qc < QC_THRESH)
+        tc.assertTrue(np.isclose(insertion['json']['extended_qc']['alignment_qc'], alignment_qc))
+    if tc.prev_traj_id:
+        traj = one.alyx.get('/trajectories?'
+                            f'&probe_id={tc.probe_id}'
+                            '&provenance=Ephys aligned histology track', clobber=True)
+        tc.assertNotEqual(tc.prev_traj_id == traj[0]['id'], trajectory_created)
+
+
 class TestUploadToFlatIron(unittest.TestCase):
+    probe_id = None
+
     @unittest.skip("Skip FTP upload test")
     @classmethod
     def setUpClass(cls) -> None:
@@ -346,8 +353,8 @@ class TestUploadToFlatIron(unittest.TestCase):
 
     def test_upload_to_flatiron(self):
         for file in self.file_paths:
-            file_registered = one.alyx.rest('datasets', 'list', session=EPHYS_SESSION,
-                                            dataset_type=file.stem)
+            file_registered = one.alyx.get(f'/datasets?&session={EPHYS_SESSION}'
+                                           f'&dataset_type={file.stem}')
             data_id = file_registered[0]['url'][-36:]
             assert(len(file_registered) == 1)
             one.alyx.rest('datasets', 'delete', id=data_id)
