@@ -7,9 +7,11 @@ from pathlib import Path
 import sys
 
 import numpy as np
+from one.api import ONE
+from iblutil.io import params
 
-from oneibl.one import ONE
-from ibllib.io import params, flags, jsonable, misc, globus, video
+from ibllib.tests import TEST_DB
+from ibllib.io import flags, misc, globus, video
 import ibllib.io.raw_data_loaders as raw
 
 
@@ -95,6 +97,8 @@ class TestsRawDataLoaders(unittest.TestCase):
 
     def setUp(self):
         self.tempfile = tempfile.NamedTemporaryFile(delete=False)
+        self.bin_session_path = Path(__file__).parent.joinpath(
+            'fixtures', 'io', 'data_loaders', "_iblrig_test_mouse_2020-01-01_001")
 
     def testFlagFileRead(self):
         # empty file should return True
@@ -172,8 +176,9 @@ class TestsRawDataLoaders(unittest.TestCase):
         # fixture file to another file in a temporary folder, with the columns swapped.
         from_file = session.joinpath('raw_video_data', '_iblrig_bodyCamera.timestamps.ssv')
         with tempfile.TemporaryDirectory() as tempdir:
-            # New file with columns swapped
-            to_file = Path(tempdir).joinpath('raw_video_data', '_iblrig_leftCamera.timestamps.ssv')
+            # New file with columns swapped (also checks loading files with UUID in name)
+            filename = f'_iblrig_leftCamera.timestamps.{uuid.uuid4()}.ssv'
+            to_file = Path(tempdir).joinpath('raw_video_data', filename)
             to_file.parent.mkdir(exist_ok=True)
             with open(from_file, 'r') as a, open(to_file, 'w') as b:
                 for i in range(5):
@@ -192,8 +197,13 @@ class TestsRawDataLoaders(unittest.TestCase):
         :return:
         """
         session = Path(__file__).parent.joinpath('extractors', 'data', 'session_ephys')
+        session2 = Path(__file__).parent.joinpath(
+            'fixtures', 'io', 'data_loaders', '_iblrig_test_mouse_2020-01-01_001'
+        )
         gpio = raw.load_camera_gpio(session, 'body', as_dicts=True)
+        gpio2 = raw.load_camera_gpio(session2, 'left', as_dicts=True)
         self.assertEqual(len(gpio), 4)  # One dict per pin
+        self.assertEqual(len(gpio2), 4)  # One dict per pin
         *gpio_, gpio_4 = gpio  # Check last dict; pin 4 should have one pulse
         self.assertTrue(all(k in ('indices', 'polarities') for k in gpio_4.keys()))
         np.testing.assert_array_equal(gpio_4['indices'], np.array([166, 172], dtype=np.int64))
@@ -214,9 +224,11 @@ class TestsRawDataLoaders(unittest.TestCase):
         with tempfile.TemporaryDirectory() as tdir:
             session_path = Path(tdir).joinpath('mouse', '2020-06-01', '001')
             session_path.joinpath('raw_video_data').mkdir(parents=True)
-            filename = session_path / 'raw_video_data' / f'_iblrig_{side}Camera.GPIO.bin'
+            # Test loads file with UUID
+            did = uuid.uuid4()  # Random uuid
+            filename = session_path / 'raw_video_data' / f'_iblrig_{side}Camera.GPIO.{did}.bin'
             np.full(1000, 1.87904819e+09, dtype=np.float64).tofile(filename)
-            with self.assertRaises(AssertionError):
+            with self.assertLogs('ibllib', level='WARNING'):
                 raw.load_camera_gpio(session_path, side, as_dicts=True)
 
             # Test dead pin array
@@ -252,27 +264,39 @@ class TestsRawDataLoaders(unittest.TestCase):
         self.assertNotEqual(count[0], 0)
         self.assertIsInstance(gpio, np.ndarray)
 
+    def test_load_camera_frameData(self):
+        import pandas as pd
+        fd_raw = raw.load_camera_frameData(self.bin_session_path, raw=True)
+        fd = raw.load_camera_frameData(self.bin_session_path)
+        # Wrong camera input file not found
+        with self.assertRaises(AssertionError):
+            raw.load_camera_frameData(self.bin_session_path, camera='right')
+        # Shape
+        self.assertTrue(fd.shape[1] == 4)
+        self.assertTrue(fd_raw.shape[1] == 4)
+        # Type
+        self.assertTrue(isinstance(fd, pd.DataFrame))
+        self.assertTrue(isinstance(fd_raw, pd.DataFrame))
+        # Column names
+        df_cols = ["Timestamp", "embeddedTimeStamp",
+                   "embeddedFrameCounter", "embeddedGPIOPinState"]
+        self.assertTrue(np.all([x in fd.columns for x in df_cols]))
+        self.assertTrue(np.all([x in fd_raw.columns for x in df_cols]))
+        # Column types
+        parsed_dtypes = {
+            "Timestamp": np.float64,
+            "embeddedTimeStamp": np.float64,
+            "embeddedFrameCounter": np.int64,
+            "embeddedGPIOPinState": object
+        }
+        self.assertTrue(fd.dtypes.to_dict() == parsed_dtypes)
+        self.assertTrue(all([x == np.int64 for x in fd_raw.dtypes]))
+
     def tearDown(self):
         self.tempfile.close()
         os.unlink(self.tempfile.name)
 
 
-class TestsJsonable(unittest.TestCase):
-
-    def testReadWrite(self):
-        tfile = tempfile.NamedTemporaryFile(delete=False)
-        data = [{'a': 'thisisa', 'b': 1, 'c': [1, 2, 3]},
-                {'a': 'thisisb', 'b': 2, 'c': [2, 3, 4]}]
-        jsonable.write(tfile.name, data)
-        data2 = jsonable.read(tfile.name)
-        self.assertEqual(data, data2)
-        jsonable.append(tfile.name, data)
-        data3 = jsonable.read(tfile.name)
-        self.assertEqual(data + data, data3)
-        tfile.close()
-        os.unlink(tfile.name)
-
-
 class TestsMisc(unittest.TestCase):
 
     def setUp(self):
@@ -349,14 +373,14 @@ class TestsGlobus(unittest.TestCase):
         expected = '/E/FlatIron/integration'
         self.assertEqual(expected, actual)
 
-    @unittest.mock.patch('ibllib.io.params.read')
+    @unittest.mock.patch('iblutil.io.params.read')
     def test_login_auto(self, mock_params):
-        client_id = 'h3u2i'
+        client_id = 'h3u2ier'
         # Test ValueError thrown with incorrect parameters
         mock_params.return_value = None  # No parameters saved
         with self.assertRaises(ValueError):
             globus.login_auto(client_id)
-        mock_params.assert_called_with('globus/default')
+        # mock_params.assert_called_with('globus/default')
 
         pars = params.from_dict({'access_token': '7r3hj89', 'expires_at_seconds': '2020-09-10'})
         mock_params.return_value = pars  # Incomplete parameter object
@@ -374,11 +398,7 @@ class TestsGlobus(unittest.TestCase):
 class TestVideo(unittest.TestCase):
     @classmethod
     def setUpClass(cls) -> None:
-        cls.one = ONE(
-            base_url="https://test.alyx.internationalbrainlab.org",
-            username="test_user",
-            password="TapetesBloc18"
-        )
+        cls.one = ONE(**TEST_DB)
 
     def setUp(self) -> None:
         self.eid = '8dd0fcb0-1151-4c97-ae35-2e2421695ad7'
@@ -388,7 +408,7 @@ class TestVideo(unittest.TestCase):
 
     def test_label_from_path(self):
         # Test file path
-        session_path = self.one.path_from_eid(self.eid)
+        session_path = self.one.eid2path(self.eid)
         video_path = session_path / 'raw_video_data' / '_iblrig_bodyCamera.raw.mp4'
         label = video.label_from_path(video_path)
         self.assertEqual('body', label)
@@ -403,6 +423,7 @@ class TestVideo(unittest.TestCase):
         self.assertIsNone(label)
 
     def test_url_from_eid(self):
+        assert self.one.mode != 'remote'
         actual = video.url_from_eid(self.eid, 'left', self.one)
         self.assertEqual(self.url, actual)
         actual = video.url_from_eid(self.eid, one=self.one)
@@ -412,6 +433,17 @@ class TestVideo(unittest.TestCase):
         expected = {'left': self.url, 'right': None}
         self.assertEqual(expected, actual)
 
+        # Test remote mode
+        old_mode = self.one.mode
+        self.one.mode = 'remote'
+        actual = video.url_from_eid(self.eid, label='left', one=self.one)
+        self.assertEqual(self.url, actual)
+        self.one.mode = old_mode
+
+        # Test arg checks
+        with self.assertRaises(ValueError):
+            video.url_from_eid(self.eid, 'back')
+
     def test_assert_valid_label(self):
         with self.assertRaises(ValueError):
             video.assert_valid_label('tail')
